==> hasktags-0.73.0-136.1-loong64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-AgA02C7TrcfFs5BHVhq81F
key:                  hasktags-0.73.0-AgA02C7TrcfFs5BHVhq81F
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  3b09281bd2555d490a64a6019a4d6949
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-AgA02C7TrcfFs5BHVhq81F
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 json-0.10-9brdcdxWRzrFsg3sW0d3xW
    microlens-platform-0.4.4.1-u1Ge9ecx9XEkFvvdmzgM2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.73.0-137-loong64.pkg.tar.zst: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-Fgpgr2krNo5H99TGxEKLwi
key:                  hasktags-0.73.0-Fgpgr2krNo5H99TGxEKLwi
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  ecf06c8796baddf73f3c04311a5c8b16
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-Fgpgr2krNo5H99TGxEKLwi
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 json-0.10-CVmt8wAUbKLCRDBxbUg8QP
    microlens-platform-0.4.4.1-7ZfpKpjp016gibCxCbEpP
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
